@@ -1,7 +1,7 @@
 /* wipe
  * $Id: random.c,v 1.1.1.1 2002/11/25 23:59:49 berke Exp $
  * by Berke Durak
- * Author may be contacted at 'echo berke1altern2org|tr 12 @.'
+ * Author may be contacted at 'echo berke1ouvaton2org|tr 12 @.'
  *
  * Cryptographically-strong (as well as weak) random data generation
  *
@@ -45,11 +45,12 @@
 #include <unistd.h>
 #include <time.h>
 #include <fcntl.h>
+#include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 
 #include "misc.h"
-#include "rc6.h"
+//#include "rc6.h"
 #include "arcfour.h"
 #include "md5.h"
 #include "random.h"
@@ -80,9 +81,9 @@ static void rand_Get128BitsPID (u8 buf[16])
   p = getpid ();
   t = time (0);
 
-  for (pt = environ; *pt; pt++) MD5Update (&md5, *pt, strlen (*pt));
-  MD5Update (&md5, (char *) &p, sizeof (p));
-  MD5Update (&md5, (char *) &t, sizeof (t));
+  for (pt = environ; *pt; pt++) MD5Update (&md5, (u8 *) *pt, strlen (*pt));
+  MD5Update (&md5, (u8 *) &p, sizeof (p));
+  MD5Update (&md5, (u8 *) &t, sizeof (t));
 
   MD5Final (buf, &md5);
 }
@@ -229,7 +230,7 @@ static void rand_Fill_libc (u8 *b, int n)
     l = rand_Get32_libc ();
 
     *((u32 *) b) = l;
-    b = (char *) (((u32 *) b) + 1);
+    b = (u8 *) (((u32 *) b) + 1);
   }
 
   if (n) {
