@@ -1,9 +1,9 @@
 /* wipe
  * $Id: wipe.c,v 1.2 2004/06/12 17:49:47 berke Exp $
  * by Berke Durak
- * Author may be contacted at 'echo berke1altern2org|tr 12 @.'
+ * Author may be contacted at 'echo berke1ouvaton2org|tr 12 @.'
  *
- * URL for wipe: http://perso.wanadoo.fr/berke/wipe/
+ * URL for wipe: http://abaababa.ouvaton.org/wipe/
  *
  * Securely erase files from magnetic media
  * Based on data from article "Secure Deletion of Data from Magnetic
@@ -13,8 +13,8 @@
 
 /*** defines */
 
-#define WIPE_VERSION "0.20"
-#define WIPE_DATE "2004-06-12"
+#define WIPE_VERSION "0.21"
+#define WIPE_DATE "2006-09-20"
 #define WIPE_CVS "$Id: wipe.c,v 1.2 2004/06/12 17:49:47 berke Exp $"
 
 /* exit codes */
@@ -719,7 +719,7 @@ static int dothejob (char *fn)
                     debugf ("lseek -> %d", l);
                     o_wipe_length = l;
 #else
-                    long l;
+                    off_t l;
                     /* find device size by seeking... might work on some devices */
                     l = lseek (fd, 0, SEEK_END);
                     if (!l) {
@@ -1088,8 +1088,8 @@ void banner ()
     fprintf (stderr, "This is wipe version " WIPE_VERSION ".\n"
             "\n"
             "Author: Berke Durak.\n"
-            "Author's e-mail address: echo berke1altern2org|tr 12 @.\n"
-            "Web site: http://perso.wanadoo.fr/berke/wipe/\n"
+            "Author's e-mail address: echo berke1ouvaton2org|tr 12 @.\n"
+            "Web site: http://abaababa.ouvaton.org/wipe/\n"
             "\n"
             "Release date: " WIPE_DATE "\n"
             "Compiled: " __DATE__ "\n"
